@@ -336,7 +336,7 @@ pytrap_getDataFmt(pytrap_trapcontext *self, PyObject *args, PyObject *keywds)
     }
 
     trap_ctx_get_data_fmt(self->trap, TRAPIFC_INPUT, ifcidx, &data_type, &fmtspec);
-    return Py_BuildValue("(is)", data_type, strdup(fmtspec));
+    return Py_BuildValue("(is)", data_type, fmtspec);
 }
 
 static PyObject *
@@ -561,8 +561,8 @@ pytrap_getTrapVersion(PyObject *self)
 {
     PyObject *t = NULL;
     t = Py_BuildValue("(ss)",
-                      strdup(trap_version),
-                      strdup(trap_git_version));
+                      trap_version,
+                      trap_git_version);
 
     return t;
 }
